diff playtree.h @ 23872:4d936284a5ec

typo fix: childs --> children
author diego
date Sat, 28 Jul 2007 14:27:55 +0000
parents 3f0d00abc073
children 3baf6a2283da
line wrap: on
line diff
--- a/playtree.h	Sat Jul 28 14:27:04 2007 +0000
+++ b/playtree.h	Sat Jul 28 14:27:55 2007 +0000
@@ -31,7 +31,7 @@
 /// \defgroup PlaytreeEntryFlags Playtree flags
 /// \ingroup Playtree
 ///@{
 /// Play the item childs in random order.
 #define PLAY_TREE_RND  (1<<0)
 /// Playtree flags used by the iterator to mark items already "randomly" played.
 #define PLAY_TREE_RND_PLAYED  (1<<8)
@@ -121,21 +121,21 @@
 
 /// Free a playtree item.
 /** \param pt Item to free.
  *  \param childs If non-zero the item's childs are recursively freed.
  */
 void
-play_tree_free(play_tree_t* pt, int childs);
+play_tree_free(play_tree_t* pt, int children);
 
 
 /// Free an item and its siblings.
 /** \param pt Item to free.
  *  \param childs If non-zero the items' childs are recursively freed.
  */
 void
-play_tree_free_list(play_tree_t* pt, int childs);
+play_tree_free_list(play_tree_t* pt, int children);
 
 
 /// Set the childs of a playtree item.
 void
 play_tree_set_child(play_tree_t* pt, play_tree_t* child);
 
@@ -158,7 +158,7 @@
 
 /// Detach an item from the tree.
 void
-play_tree_remove(play_tree_t* pt, int free_it,int with_childs);
+play_tree_remove(play_tree_t* pt, int free_it,int with_children);
 
 /// Add a file to an item.
 void
@@ -199,7 +199,7 @@
 /// Step an iterator.
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
  *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
 int 
@@ -208,7 +208,7 @@
 /// Step up, useful to break a loop, etc.
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
  *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
 int
@@ -31,7 +31,7 @@
 /// \ingroup Playtree
 ///@{
-/// Play the item childs in random order.
+/// Play the item children in random order.
 #define PLAY_TREE_RND  (1<<0)
 /// Playtree flags used by the iterator to mark items already "randomly" played.
@@ -121,21 +121,21 @@
 /// Free a playtree item.
 /** \param pt Item to free.
- *  \param childs If non-zero the item's childs are recursively freed.
+ *  \param children If non-zero the item's children are recursively freed.
  */
 void
@@ -121,21 +121,21 @@
 /// Free an item and its siblings.
 /** \param pt Item to free.
- *  \param childs If non-zero the items' childs are recursively freed.
+ *  \param children If non-zero the items' children are recursively freed.
  */
 void
@@ -121,21 +121,21 @@
 
 
-/// Set the childs of a playtree item.
+/// Set the children of a playtree item.
 void
 play_tree_set_child(play_tree_t* pt, play_tree_t* child);
@@ -199,7 +199,7 @@
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
- *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
+ *  \param with_node TRUE == stop on nodes with children, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */
@@ -208,7 +208,7 @@
 /** \param iter The iterator.
  *  \param d The direction: d > 0 == next , d < 0 == prev
- *  \param with_node TRUE == stop on nodes with childs, FALSE == go directly to the next child
+ *  \param with_node TRUE == stop on nodes with children, FALSE == go directly to the next child
  *  \return See \ref PlaytreeIterReturn.
  */